'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

// e.g. for sport:
// const [sport300, sport400, sport500, sport600, sport800] = colors.blue

var colors = {
  reds: ["#AB0613", //news-300
  "#C70000", //news-400
  "#FF5943", //news-500
  "#FFBAC8", //news-600
  "#FFF4F2"],
  oranges: ["#AB0613", //opinion-300
  "#E05E00", //opinion-400
  "#FF7F0F", //opinion-500
  "#F9B376", //opinion-600
  "#FEF9F5"],
  blues: ["#005689", //sport-300
  "#0084C6", //sport-400
  "#00B2FF", //sport-500
  "#90DCFF", //sport-600
  "#F1F8FC", //sport-800
  "#041F4A", //brand-300
  "#052962", //brand-400
  "#007ABC", //brand-500
  "#506991", //brand-600
  "#C1D8FC"],
  browns: ["#6B5840", //culture-300
  "#A1845C", //culture-400
  "#EACCA0", //culture-500
  "#E7D4B9", //culture-600
  "#FBF6EF"],
  pinks: ["#7D0068", //lifestyle-300
  "#BB3B80", //lifestyle-400
  "#FFABDB", //lifestyle-500
  "#FEC8D3", //lifestyle-600
  "#FEEEF7"],
  yellows: ["#F3C100", //highlight-300
  "#FFE500"],
  greens: ["#185E36", "#22874D", //success-400
  "#65A897", //labs-300
  "#69D1CA"],
  grays: ["#121212", //neutral-7
  "#333333", //neutral-20
  "#767676", //neutral-46
  "#999999", //neutral-60
  "#DCDCDC", //neutral-86
  "#EDEDED", //neutral-93
  "#F6F6F6", //neutral-97
  "#FFFFFF"]
};
var space = [0, 4, 8, 12, 20, 24, 36, 48, 96];
var size = [24, 36, 44];
var breakpoints = [740, 980, 1140, 1300]; // Diverges from https://system-ui.com
// At these widths, there are tweaks to the
// fluid grid on mobile devices

var tweakpoints = [320, 375, 480, 660];
var transitions = [".2s cubic-bezier(.64, .57, .67, 1.53)", ".3s ease-in-out", ".65s ease-in-out"];

var transitions$1 = {
  "short": transitions[0],
  medium: transitions[1],
  "long": transitions[2]
};

var breakpoints$1 = {
  mobile: tweakpoints[0],
  mobileMedium: tweakpoints[1],
  mobileLandscape: tweakpoints[2],
  phablet: tweakpoints[3],
  tablet: breakpoints[0],
  desktop: breakpoints[1],
  leftCol: breakpoints[2],
  wide: breakpoints[3]
};

var brand = {
  300: colors.blues[5],
  400: colors.blues[6],
  500: colors.blues[7],
  600: colors.blues[8],
  800: colors.blues[9],
  // legacy names: please do not use
  dark: colors.blues[5],
  main: colors.blues[6],
  bright: colors.blues[7],
  pastel: colors.blues[8],
  faded: colors.blues[9]
};
var brandAlt = {
  300: colors.yellows[0],
  400: colors.yellows[1],
  // legacy names: please do not use
  dark: colors.yellows[0],
  main: colors.yellows[1] // continue to expose legacy name for compatibility

};
var brandYellow = brandAlt;
var neutral = {
  7: colors.grays[0],
  20: colors.grays[1],
  46: colors.grays[2],
  60: colors.grays[3],
  86: colors.grays[4],
  93: colors.grays[5],
  97: colors.grays[6],
  100: colors.grays[7],
  // TODO: move this into background.ts
  specialReport: "#3F464A"
};
var error = {
  400: colors.reds[1],
  500: colors.reds[2],
  // legacy names: please do not use
  main: colors.reds[1],
  bright: colors.reds[2]
};
var success = {
  400: colors.greens[1],
  // legacy names: please do not use
  main: colors.greens[1]
};
var news = {
  300: colors.reds[0],
  400: colors.reds[1],
  500: colors.reds[2],
  600: colors.reds[3],
  800: colors.reds[4],
  // legacy names: please do not use
  dark: colors.reds[0],
  main: colors.reds[1],
  bright: colors.reds[2],
  pastel: colors.reds[3],
  faded: colors.reds[4]
};
var opinion = {
  300: colors.oranges[0],
  400: colors.oranges[1],
  500: colors.oranges[2],
  600: colors.oranges[3],
  800: colors.oranges[4],
  // legacy names: please do not use
  dark: colors.oranges[0],
  main: colors.oranges[1],
  bright: colors.oranges[2],
  pastel: colors.oranges[3],
  faded: colors.oranges[4]
};
var sport = {
  300: colors.blues[0],
  400: colors.blues[1],
  500: colors.blues[2],
  600: colors.blues[3],
  800: colors.blues[4],
  // legacy names: please do not use
  dark: colors.blues[0],
  main: colors.blues[1],
  bright: colors.blues[2],
  pastel: colors.blues[3],
  faded: colors.blues[4]
};
var culture = {
  300: colors.browns[0],
  400: colors.browns[1],
  500: colors.browns[2],
  600: colors.browns[3],
  800: colors.browns[4],
  // legacy names: please do not use
  dark: colors.browns[0],
  main: colors.browns[1],
  bright: colors.browns[2],
  pastel: colors.browns[3],
  faded: colors.browns[4]
};
var lifestyle = {
  300: colors.pinks[0],
  400: colors.pinks[1],
  500: colors.pinks[2],
  600: colors.pinks[3],
  800: colors.pinks[4],
  // legacy names: please do not use
  dark: colors.pinks[0],
  main: colors.pinks[1],
  bright: colors.pinks[2],
  pastel: colors.pinks[3],
  faded: colors.pinks[4]
};
var labs = {
  300: colors.greens[2],
  400: colors.greens[3],
  // legacy names: please do not use
  dark: colors.greens[2],
  main: colors.greens[3]
};

var background = {
  primary: neutral[100],
  buttonPrimary: brand[400],
  buttonPrimaryHover: "#234B8A",
  buttonSecondary: brand[800],
  buttonSecondaryHover: "#ACC9F7",
  checkboxChecked: brand[500],
  radioChecked: brand[500],
  textInput: neutral[100]
};
var brandBackground = {
  primary: brand[400],
  buttonPrimary: neutral[100],
  buttonPrimaryHover: "#E0E0E0",
  buttonSecondary: brand[600],
  buttonSecondaryHover: "#234B8A",
  checkboxChecked: neutral[100],
  radioChecked: neutral[100]
};
var brandAltBackground = {
  primary: brandAlt[400],
  buttonPrimary: neutral[7],
  buttonPrimaryHover: "#454545",
  buttonSecondary: brandAlt[300],
  buttonSecondaryHover: "#F2AE00"
};
var inverseBackground = {
  primary: "#1A1A1A"
};

var border = {
  primary: neutral[60],
  secondary: neutral[86],
  error: error[400],
  focusHalo: sport[500],
  checkbox: neutral[60],
  checkboxHover: brand[500],
  checkboxChecked: brand[500],
  checkboxError: error[400],
  radio: neutral[60],
  radioHover: brand[500],
  radioError: error[400],
  textInput: neutral[60],
  textInputError: error[400]
};
var brandBorder = {
  error: error[500],
  checkbox: brand[800],
  checkboxHover: neutral[100],
  checkboxChecked: neutral[100],
  checkboxError: error[500],
  radio: brand[800],
  radioHover: neutral[100],
  radioError: error[500]
};

var line = {
  primary: neutral[86]
};
var brandLine = {
  primary: brand[600]
};
var brandAltLine = {
  primary: neutral[7]
};

var text = {
  primary: neutral[7],
  secondary: neutral[46],
  error: error[400],
  buttonPrimary: neutral[100],
  buttonSecondary: brand[400],
  checkbox: neutral[7],
  checkboxSupporting: neutral[46],
  checkboxIndeterminate: neutral[46],
  linkPrimary: brand[500],
  linkPrimaryHover: brand[500],
  linkSecondary: neutral[7],
  linkSecondaryHover: neutral[7],
  radio: neutral[7],
  radioSupporting: neutral[46],
  textInput: neutral[7],
  textInputLabel: neutral[7],
  textInputOptionalLabel: neutral[46],
  textInputSupporting: neutral[46],
  textInputError: error[400]
};
var brandText = {
  primary: neutral[100],
  secondary: brand[800],
  error: error[500],
  buttonPrimary: brand[400],
  buttonSecondary: neutral[100],
  checkbox: neutral[100],
  checkboxSupporting: brand[800],
  checkboxIndeterminate: brand[800],
  linkPrimary: neutral[100],
  linkPrimaryHover: neutral[100],
  radio: neutral[100],
  radioSupporting: brand[800]
};
var brandAltText = {
  primary: neutral[7],
  secondary: neutral[60],
  buttonPrimary: neutral[100],
  buttonSecondary: neutral[7],
  linkPrimary: neutral[7],
  linkPrimaryHover: neutral[7]
};

var size$1 = {
  small: size[0],
  medium: size[1],
  large: size[2]
};

var space$1 = {
  1: space[1],
  2: space[2],
  3: space[3],
  5: space[4],
  6: space[5],
  9: space[6],
  12: space[7],
  24: space[8]
};

var palette = {
  // functional colours (default)
  background: background,
  border: border,
  line: line,
  text: text,
  // functional colours (inverse)
  inverseBackground: inverseBackground,
  // functional colours (brand)
  brandBackground: brandBackground,
  brandBorder: brandBorder,
  brandLine: brandLine,
  brandText: brandText,
  // functional colours (brandAlt)
  brandAltBackground: brandAltBackground,
  brandAltLine: brandAltLine,
  brandAltText: brandAltText,
  // global colours
  brand: brand,
  brandAlt: brandAlt,
  brandYellow: brandYellow,
  neutral: neutral,
  error: error,
  success: success,
  news: news,
  opinion: opinion,
  sport: sport,
  culture: culture,
  lifestyle: lifestyle,
  labs: labs
};

exports.background = background;
exports.border = border;
exports.brand = brand;
exports.brandAlt = brandAlt;
exports.brandAltBackground = brandAltBackground;
exports.brandAltLine = brandAltLine;
exports.brandAltText = brandAltText;
exports.brandBackground = brandBackground;
exports.brandBorder = brandBorder;
exports.brandLine = brandLine;
exports.brandText = brandText;
exports.brandYellow = brandYellow;
exports.breakpoints = breakpoints$1;
exports.culture = culture;
exports.error = error;
exports.inverseBackground = inverseBackground;
exports.labs = labs;
exports.lifestyle = lifestyle;
exports.line = line;
exports.neutral = neutral;
exports.news = news;
exports.opinion = opinion;
exports.palette = palette;
exports.size = size$1;
exports.space = space$1;
exports.sport = sport;
exports.success = success;
exports.text = text;
exports.transitions = transitions$1;
