'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

function ownKeys(object, enumerableOnly) {
  var keys = Object.keys(object);

  if (Object.getOwnPropertySymbols) {
    var symbols = Object.getOwnPropertySymbols(object);
    if (enumerableOnly) symbols = symbols.filter(function (sym) {
      return Object.getOwnPropertyDescriptor(object, sym).enumerable;
    });
    keys.push.apply(keys, symbols);
  }

  return keys;
}

function _objectSpread2(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i] != null ? arguments[i] : {};

    if (i % 2) {
      ownKeys(source, true).forEach(function (key) {
        _defineProperty(target, key, source[key]);
      });
    } else if (Object.getOwnPropertyDescriptors) {
      Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
    } else {
      ownKeys(source).forEach(function (key) {
        Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
      });
    }
  }

  return target;
}

// e.g. for sport:
// const [sport300, sport400, sport500, sport600, sport800] = colors.blue

var colors = {
  reds: ["#AB0613", //news-300
  "#C70000", //news-400
  "#FF5943", //news-500
  "#FFBAC8", //news-600
  "#FFF4F2"],
  oranges: ["#AB0613", //opinion-300
  "#E05E00", //opinion-400
  "#FF7F0F", //opinion-500
  "#F9B376", //opinion-600
  "#FEF9F5"],
  blues: ["#005689", //sport-300
  "#0084C6", //sport-400
  "#00B2FF", //sport-500
  "#90DCFF", //sport-600
  "#F1F8FC", //sport-800
  "#041F4A", //brand-300
  "#052962", //brand-400
  "#007ABC", //brand-500
  "#506991", //brand-600
  "#C1D8FC"],
  browns: ["#6B5840", //culture-300
  "#A1845C", //culture-400
  "#EACCA0", //culture-500
  "#E7D4B9", //culture-600
  "#FBF6EF"],
  pinks: ["#7D0068", //lifestyle-300
  "#BB3B80", //lifestyle-400
  "#FFABDB", //lifestyle-500
  "#FEC8D3", //lifestyle-600
  "#FEEEF7"],
  yellows: ["#F3C100", //highlight-300
  "#FFE500"],
  greens: ["#185E36", "#22874D", //success-400
  "#65A897", //labs-300
  "#69D1CA"],
  grays: ["#121212", //neutral-7
  "#333333", //neutral-20
  "#767676", //neutral-46
  "#999999", //neutral-60
  "#DCDCDC", //neutral-86
  "#EDEDED", //neutral-93
  "#F6F6F6", //neutral-97
  "#FFFFFF"]
};

var brand = {
  300: colors.blues[5],
  400: colors.blues[6],
  500: colors.blues[7],
  600: colors.blues[8],
  800: colors.blues[9],
  // legacy names: please do not use
  dark: colors.blues[5],
  main: colors.blues[6],
  bright: colors.blues[7],
  pastel: colors.blues[8],
  faded: colors.blues[9]
};
var brandAlt = {
  300: colors.yellows[0],
  400: colors.yellows[1],
  // legacy names: please do not use
  dark: colors.yellows[0],
  main: colors.yellows[1] // continue to expose legacy name for compatibility

};
var neutral = {
  7: colors.grays[0],
  20: colors.grays[1],
  46: colors.grays[2],
  60: colors.grays[3],
  86: colors.grays[4],
  93: colors.grays[5],
  97: colors.grays[6],
  100: colors.grays[7],
  // TODO: move this into background.ts
  specialReport: "#3F464A"
};
var error = {
  400: colors.reds[1],
  500: colors.reds[2],
  // legacy names: please do not use
  main: colors.reds[1],
  bright: colors.reds[2]
};
var sport = {
  300: colors.blues[0],
  400: colors.blues[1],
  500: colors.blues[2],
  600: colors.blues[3],
  800: colors.blues[4],
  // legacy names: please do not use
  dark: colors.blues[0],
  main: colors.blues[1],
  bright: colors.blues[2],
  pastel: colors.blues[3],
  faded: colors.blues[4]
};

var background = {
  primary: neutral[100],
  buttonPrimary: brand[400],
  buttonPrimaryHover: "#234B8A",
  buttonSecondary: brand[800],
  buttonSecondaryHover: "#ACC9F7",
  checkboxChecked: brand[500],
  radioChecked: brand[500],
  textInput: neutral[100]
};
var brandBackground = {
  primary: brand[400],
  buttonPrimary: neutral[100],
  buttonPrimaryHover: "#E0E0E0",
  buttonSecondary: brand[600],
  buttonSecondaryHover: "#234B8A",
  checkboxChecked: neutral[100],
  radioChecked: neutral[100]
};
var brandAltBackground = {
  primary: brandAlt[400],
  buttonPrimary: neutral[7],
  buttonPrimaryHover: "#454545",
  buttonSecondary: brandAlt[300],
  buttonSecondaryHover: "#F2AE00"
};

var border = {
  primary: neutral[60],
  secondary: neutral[86],
  error: error[400],
  focusHalo: sport[500],
  checkbox: neutral[60],
  checkboxHover: brand[500],
  checkboxChecked: brand[500],
  checkboxError: error[400],
  radio: neutral[60],
  radioHover: brand[500],
  radioError: error[400],
  textInput: neutral[60],
  textInputError: error[400]
};
var brandBorder = {
  error: error[500],
  checkbox: brand[800],
  checkboxHover: neutral[100],
  checkboxChecked: neutral[100],
  checkboxError: error[500],
  radio: brand[800],
  radioHover: neutral[100],
  radioError: error[500]
};

var text = {
  primary: neutral[7],
  secondary: neutral[46],
  error: error[400],
  buttonPrimary: neutral[100],
  buttonSecondary: brand[400],
  checkbox: neutral[7],
  checkboxSupporting: neutral[46],
  checkboxIndeterminate: neutral[46],
  linkPrimary: brand[500],
  linkPrimaryHover: brand[500],
  linkSecondary: neutral[7],
  linkSecondaryHover: neutral[7],
  radio: neutral[7],
  radioSupporting: neutral[46],
  textInput: neutral[7],
  textInputLabel: neutral[7],
  textInputOptionalLabel: neutral[46],
  textInputSupporting: neutral[46],
  textInputError: error[400]
};
var brandText = {
  primary: neutral[100],
  secondary: brand[800],
  error: error[500],
  buttonPrimary: brand[400],
  buttonSecondary: neutral[100],
  checkbox: neutral[100],
  checkboxSupporting: brand[800],
  checkboxIndeterminate: brand[800],
  linkPrimary: neutral[100],
  linkPrimaryHover: neutral[100],
  radio: neutral[100],
  radioSupporting: brand[800]
};
var brandAltText = {
  primary: neutral[7],
  secondary: neutral[60],
  buttonPrimary: neutral[100],
  buttonSecondary: neutral[7],
  linkPrimary: neutral[7],
  linkPrimaryHover: neutral[7]
};

var buttonDefault = {
  button: {
    textPrimary: text.buttonPrimary,
    backgroundPrimary: background.buttonPrimary,
    backgroundPrimaryHover: background.buttonPrimaryHover,
    textSecondary: text.buttonSecondary,
    backgroundSecondary: background.buttonSecondary,
    backgroundSecondaryHover: background.buttonSecondaryHover,
    textTertiary: text.buttonSecondary,
    backgroundTertiary: background.primary
  }
};
var buttonBrand = {
  button: {
    textPrimary: brandText.buttonPrimary,
    backgroundPrimary: brandBackground.buttonPrimary,
    backgroundPrimaryHover: brandBackground.buttonPrimaryHover,
    textSecondary: brandText.buttonSecondary,
    backgroundSecondary: brandBackground.buttonSecondary,
    backgroundSecondaryHover: brandBackground.buttonSecondaryHover,
    textTertiary: brandText.buttonSecondary,
    backgroundTertiary: brandBackground.primary
  }
};
var buttonBrandAlt = {
  button: {
    textPrimary: brandAltText.buttonPrimary,
    backgroundPrimary: brandAltBackground.buttonPrimary,
    backgroundPrimaryHover: brandAltBackground.buttonPrimaryHover,
    textSecondary: brandAltText.buttonSecondary,
    backgroundSecondary: brandAltBackground.buttonSecondary,
    backgroundSecondaryHover: brandAltBackground.buttonSecondaryHover,
    textTertiary: brandAltText.buttonSecondary,
    backgroundTertiary: brandAltBackground.primary
  } // continue to expose legacy theme names

};
var buttonLight = buttonDefault;
var buttonBrandYellow = buttonBrandAlt;

var inlineErrorDefault = {
  inlineError: {
    text: text.error
  }
};
var inlineErrorBrand = {
  inlineError: {
    text: brandText.error
  } // continue to expose legacy theme names

};
var inlineErrorLight = inlineErrorDefault;

var checkboxDefault = _objectSpread2({
  checkbox: {
    border: border.checkbox,
    borderHover: border.checkboxHover,
    borderChecked: border.checkboxChecked,
    borderError: border.checkboxError,
    backgroundChecked: background.checkboxChecked,
    text: text.checkbox,
    textSupporting: text.checkboxSupporting,
    textIndeterminate: text.checkboxIndeterminate
  }
}, inlineErrorDefault);
var checkboxBrand = _objectSpread2({
  checkbox: {
    border: brandBorder.checkbox,
    borderHover: brandBorder.checkboxHover,
    borderChecked: brandBorder.checkboxChecked,
    borderError: brandBorder.checkboxError,
    backgroundChecked: brandBackground.checkboxChecked,
    text: brandText.checkbox,
    textSupporting: brandText.checkboxSupporting,
    textIndeterminate: brandText.checkboxIndeterminate
  }
}, inlineErrorBrand); // continue to expose legacy theme names

var checkboxLight = checkboxDefault;

var linkDefault = {
  link: {
    textPrimary: text.linkPrimary,
    textPrimaryHover: text.linkPrimaryHover,
    textSecondary: text.linkSecondary,
    textSecondaryHover: text.linkSecondaryHover
  }
};
var linkBrand = {
  link: {
    textPrimary: brandText.linkPrimary,
    textPrimaryHover: brandText.linkPrimaryHover
  }
};
var linkBrandAlt = {
  link: {
    textPrimary: brandAltText.linkPrimary,
    textPrimaryHover: brandAltText.linkPrimaryHover
  } // continue to expose legacy theme names

};
var linkLight = linkDefault;
var linkBrandYellow = linkBrandAlt;

var radioDefault = _objectSpread2({
  radio: {
    borderHover: border.radioHover,
    border: border.radio,
    backgroundChecked: background.radioChecked,
    text: text.radio,
    textSupporting: text.radioSupporting,
    borderError: border.radioError
  }
}, inlineErrorLight);
var radioBrand = _objectSpread2({
  radio: {
    borderHover: brandBorder.radioHover,
    border: brandBorder.radio,
    backgroundChecked: brandBackground.radioChecked,
    text: brandText.radio,
    textSupporting: brandText.radioSupporting,
    borderError: brandBorder.radioError
  }
}, inlineErrorBrand); // continue to expose legacy theme names

var radioLight = radioDefault;

var textInputDefault = _objectSpread2({
  textInput: {
    textInput: text.textInput,
    textLabel: text.textInputLabel,
    textOptionalLabel: text.textInputOptionalLabel,
    textSupporting: text.textInputSupporting,
    textError: text.textInputError,
    backgroundInput: background.textInput,
    border: border.textInput,
    borderError: border.textInputError
  }
}, inlineErrorDefault); // continue to expose legacy theme names

var textInputLight = textInputDefault;

var defaultTheme = _objectSpread2({}, buttonDefault, {}, checkboxDefault, {}, inlineErrorDefault, {}, linkDefault, {}, radioDefault, {}, textInputDefault, {}, buttonLight, {}, checkboxLight, {}, inlineErrorLight, {}, linkLight, {}, radioLight, {}, textInputLight);
var brand$1 = _objectSpread2({}, buttonBrand, {}, checkboxBrand, {}, inlineErrorBrand, {}, linkBrand, {}, radioBrand);
var brandAlt$1 = _objectSpread2({}, buttonBrandAlt, {}, linkBrandAlt, {}, buttonBrandYellow, {}, linkBrandYellow); // continue to expose legacy theme names

var light = defaultTheme;
var brandYellow = brandAlt$1;

exports.brand = brand$1;
exports.brandAlt = brandAlt$1;
exports.brandYellow = brandYellow;
exports.buttonBrand = buttonBrand;
exports.buttonBrandAlt = buttonBrandAlt;
exports.buttonBrandYellow = buttonBrandYellow;
exports.buttonDefault = buttonDefault;
exports.buttonLight = buttonLight;
exports.checkboxBrand = checkboxBrand;
exports.checkboxDefault = checkboxDefault;
exports.checkboxLight = checkboxLight;
exports.defaultTheme = defaultTheme;
exports.inlineErrorBrand = inlineErrorBrand;
exports.inlineErrorDefault = inlineErrorDefault;
exports.inlineErrorLight = inlineErrorLight;
exports.light = light;
exports.linkBrand = linkBrand;
exports.linkBrandAlt = linkBrandAlt;
exports.linkBrandYellow = linkBrandYellow;
exports.linkDefault = linkDefault;
exports.linkLight = linkLight;
exports.radioBrand = radioBrand;
exports.radioDefault = radioDefault;
exports.radioLight = radioLight;
exports.textInputDefault = textInputDefault;
exports.textInputLight = textInputLight;
