'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

var fontSizes = [12, 15, 17, 20, 24, 28, 34, 42, 50, 70];
var fonts = {
  titlepiece: "GT Guardian Titlepiece, Georgia, serif",
  headlineSerif: "GH Guardian Headline, Georgia, serif",
  bodySerif: "GuardianTextEgyptian, Georgia, serif",
  bodySans: "GuardianTextSans, Helvetica Neue, Helvetica, Arial, Lucida Grande, sans-serif"
};
var lineHeights = [1.15, 1.35, 1.5];
var fontWeights = [300, 400, 500, 700]; // Arrays of colours should have pillar colors first

var fontSizesRem = fontSizes.map(function (fontSize) {
  return fontSize / 16;
});
var titlepieceSizes = {
  small: fontSizesRem[7],
  //42px
  medium: fontSizesRem[8],
  //50px
  large: fontSizesRem[9] //70px

};
var headlineSizes = {
  xxxsmall: fontSizesRem[2],
  //17px
  xxsmall: fontSizesRem[3],
  //20px
  xsmall: fontSizesRem[4],
  //24px
  small: fontSizesRem[5],
  //28px
  medium: fontSizesRem[6],
  //34px
  large: fontSizesRem[7],
  //42px
  xlarge: fontSizesRem[8] //50px

};
var bodySizes = {
  small: fontSizesRem[1],
  //15px
  medium: fontSizesRem[2] //17px

};
var textSansSizes = {
  xsmall: fontSizesRem[0],
  //12px
  small: fontSizesRem[1],
  //15px
  medium: fontSizesRem[2],
  //17px
  large: fontSizesRem[3],
  //20px
  xlarge: fontSizesRem[4] //24px

};
var fontSizeMapping = {
  titlepiece: titlepieceSizes,
  headline: headlineSizes,
  body: bodySizes,
  textSans: textSansSizes
};
var fontMapping = {
  titlepiece: fonts.titlepiece,
  headline: fonts.headlineSerif,
  body: fonts.bodySerif,
  textSans: fonts.bodySans
};
var lineHeightMapping = {
  tight: lineHeights[0],
  regular: lineHeights[1],
  loose: lineHeights[2]
};
var fontWeightMapping = {
  light: fontWeights[0],
  regular: fontWeights[1],
  medium: fontWeights[2],
  bold: fontWeights[3]
};
var availableFonts = {
  titlepiece: {
    bold: {
      hasItalic: false
    }
  },
  headline: {
    light: {
      hasItalic: true
    },
    medium: {
      hasItalic: true
    },
    bold: {
      hasItalic: false
    }
  },
  body: {
    regular: {
      hasItalic: true
    },
    bold: {
      hasItalic: true
    }
  },
  textSans: {
    regular: {
      hasItalic: true
    },
    bold: {
      hasItalic: false
    }
  }
};

var fs = function fs(category, level, _ref) {
  var lineHeight = _ref.lineHeight,
      fontWeight = _ref.fontWeight,
      italic = _ref.italic;
  var fontFamilyValue = fontMapping[category];
  var fontSizeValue = fontSizeMapping[category][level];
  var lineHeightValue = lineHeightMapping[lineHeight]; // TODO: consider logging an error in development if a requested
  // font is unavailable

  var requestedFont = availableFonts[category][fontWeight];
  var fontWeightValue = requestedFont ? fontWeightMapping[fontWeight] : "";
  var fontStyleValue = italic && requestedFont && requestedFont.hasItalic ? "italic" : "";
  return "\n\tfont-family: ".concat(fontFamilyValue, ";\n\tfont-size: ").concat(fontSizeValue, "rem;\n\tline-height: ").concat(lineHeightValue, ";\n\t").concat(fontWeightValue ? "font-weight: ".concat(fontWeightValue) : "", ";\n\t").concat(fontStyleValue ? "font-style: ".concat(fontStyleValue) : "", ";\n\t");
};

var titlepiece = Object.keys(titlepieceSizes).reduce(function (acc, key) {
  return Object.assign({}, acc, _defineProperty({}, key, function (options) {
    var defaultOptions = {
      lineHeight: "tight",
      fontWeight: "bold",
      italic: false
    };
    var fsOptions = Object.assign(defaultOptions, options);
    return fs("titlepiece", key, fsOptions);
  }));
}, {});
var headline = Object.keys(headlineSizes).reduce(function (acc, key) {
  return Object.assign({}, acc, _defineProperty({}, key, function (options) {
    var defaultOptions = {
      lineHeight: "tight",
      fontWeight: "medium",
      italic: false
    };
    var fsOptions = Object.assign(defaultOptions, options);
    return fs("headline", key, fsOptions);
  }));
}, {});
var body = Object.keys(bodySizes).reduce(function (acc, key) {
  return Object.assign({}, acc, _defineProperty({}, key, function (options) {
    var defaultOptions = {
      lineHeight: "loose",
      fontWeight: "regular",
      italic: false
    };
    var fsOptions = Object.assign(defaultOptions, options);
    return fs("body", key, fsOptions);
  }));
}, {});
var textSans = Object.keys(textSansSizes).reduce(function (acc, key) {
  return Object.assign({}, acc, _defineProperty({}, key, function (options) {
    var defaultOptions = {
      lineHeight: "loose",
      fontWeight: "regular",
      italic: false
    };
    var fsOptions = Object.assign(defaultOptions, options);
    return fs("textSans", key, fsOptions);
  }));
}, {});
Object.freeze(titlepieceSizes);
Object.freeze(headlineSizes);
Object.freeze(bodySizes);
Object.freeze(textSansSizes);

exports.body = body;
exports.bodySizes = bodySizes;
exports.headline = headline;
exports.headlineSizes = headlineSizes;
exports.textSans = textSans;
exports.textSansSizes = textSansSizes;
exports.titlepiece = titlepiece;
exports.titlepieceSizes = titlepieceSizes;
